@@ -1,55 +1,38 @@
 # import json
-import asyncio
 import struct
 
-from ..const import CODE, BODY_TYPE, DATA, MESSAGE, ScreenLogicWarning
+from ..const import CODE, BODY_TYPE, DATA
 from .protocol import ScreenLogicProtocol
+from .request import async_make_request
 from .utility import getSome, getString
 
 
-async def async_request_pool_config(protocol: ScreenLogicProtocol, data):
-    try:
-        await asyncio.wait_for(
-            (
-                request := protocol.await_send_message(
-                    CODE.CTRLCONFIG_QUERY,
-                    struct.pack("<2I", 0, 0),  # 0,1 may yield different return
-                )
-            ),
-            MESSAGE.COM_TIMEOUT,
-        )
-        if not request.cancelled():
-            decode_pool_config(request.result(), data)
-    except asyncio.TimeoutError:
-        raise ScreenLogicWarning("Timeout polling pool config")
+async def async_request_pool_config(protocol: ScreenLogicProtocol, data: dict) -> bytes:
+    if result := await async_make_request(
+        protocol,
+        CODE.CTRLCONFIG_QUERY,
+        struct.pack("<2I", 0, 0),  # 0,1 yields different return
+    ):
+        decode_pool_config(result, data)
+        return result
 
 
-def decode_pool_config(buff, data):
-    # print(buff)
-    if DATA.KEY_CONFIG not in data:
-        data[DATA.KEY_CONFIG] = {}
-
-    config = data[DATA.KEY_CONFIG]
+def decode_pool_config(buff: bytes, data: dict) -> dict:
+    config: dict = data.setdefault(DATA.KEY_CONFIG, {})
 
     controllerID, offset = getSome("I", buff, 0)
     config["controller_id"] = {"name": "Controller ID", "value": controllerID}
 
-    if DATA.KEY_BODIES not in data:
-        data[DATA.KEY_BODIES] = {}
-
-    bodies = data[DATA.KEY_BODIES]
+    bodies: dict = data.setdefault(DATA.KEY_BODIES, {})
 
     for i in range(2):
-        if i not in bodies:
-            bodies[i] = {}
-
-        currentBody = bodies[i]
+        currentBody: dict = bodies.setdefault(i, {})
 
         minSetPoint, offset = getSome("B", buff, offset)
         MINspName = "{} Minimum Set Point".format(BODY_TYPE.NAME_FOR_NUM[i])
         currentBody["min_set_point"] = {"name": MINspName, "value": minSetPoint}
         maxSetPoint, offset = getSome("B", buff, offset)
-        MAXspName = "{} Minimum Set Point".format(BODY_TYPE.NAME_FOR_NUM[i])
+        MAXspName = "{} Maximum Set Point".format(BODY_TYPE.NAME_FOR_NUM[i])
         currentBody["max_set_point"] = {"name": MAXspName, "value": maxSetPoint}
 
     degC, offset = getSome("B", buff, offset)
@@ -77,19 +60,13 @@ def decode_pool_config(buff, data):
     circuitCount, offset = getSome("I", buff, offset)
     config["circuit_count"] = {"name": "Number of Circuits", "value": circuitCount}
 
-    if DATA.KEY_CIRCUITS not in data:
-        data[DATA.KEY_CIRCUITS] = {}
-
-    circuits = data[DATA.KEY_CIRCUITS]
+    circuits: dict = data.setdefault(DATA.KEY_CIRCUITS, {})
 
     for i in range(circuitCount):
 
         circuitID, offset = getSome("i", buff, offset)
 
-        if circuitID not in data[DATA.KEY_CIRCUITS]:
-            circuits[circuitID] = {}
-
-        currentCircuit = circuits[circuitID]
+        currentCircuit = circuits.setdefault(circuitID, {})
 
         currentCircuit["id"] = circuitID
 
@@ -124,16 +101,16 @@ def decode_pool_config(buff, data):
         cDefaultRT, offset = getSome("H", buff, offset)
         currentCircuit["default_rt"] = cDefaultRT
 
-        offset = offset + struct.calcsize("2B")
+        unknown1, offset = getSome("B", buff, offset)
+        currentCircuit["unknown1"] = unknown1
+
+        unknown2, offset = getSome("B", buff, offset)
+        currentCircuit["unknown2"] = unknown2
 
     colorCount, offset = getSome("I", buff, offset)
     config["color_count"] = {"name": "Number of Colors", "value": colorCount}
 
-    if (
-        DATA.KEY_COLORS not in data[DATA.KEY_CONFIG]
-        or len(config[DATA.KEY_COLORS]) != colorCount
-    ):
-        config[DATA.KEY_COLORS] = [{} for x in range(colorCount)]
+    colors = config.setdefault(DATA.KEY_COLORS, [{} for x in range(colorCount)])
 
     for i in range(colorCount):
         paddedColorName, offset = getString(buff, offset)
@@ -141,23 +118,20 @@ def decode_pool_config(buff, data):
         rgbR, offset = getSome("I", buff, offset)
         rgbG, offset = getSome("I", buff, offset)
         rgbB, offset = getSome("I", buff, offset)
-        config[DATA.KEY_COLORS][i] = {"name": colorName, "value": (rgbR, rgbG, rgbB)}
+        colors[i] = {"name": colorName, "value": (rgbR, rgbG, rgbB)}
 
     pumpCircuitCount = 8
-    if DATA.KEY_PUMPS not in data:
-        data[DATA.KEY_PUMPS] = {}
 
-    pumps = data[DATA.KEY_PUMPS]
+    pumps: dict = data.setdefault(DATA.KEY_PUMPS, {})
 
     for i in range(pumpCircuitCount):
-        if i not in pumps:
-            pumps[i] = {}
+        currentPump = pumps.setdefault(i, {})
+
         pumpData, offset = getSome("B", buff, offset)
-        pumps[i]["data"] = pumpData
+        currentPump["data"] = pumpData
 
     interfaceTabFlags, offset = getSome("I", buff, offset)
     config["interface_tab_flags"] = interfaceTabFlags
 
     showAlarms, offset = getSome("I", buff, offset)
     config["show_alarms"] = showAlarms
-    # print(json.dumps(data, indent=4))
